Create a simple dashboard based on Bootstrap templates.

# Licences

This example uses vendored code from the following projects:

* https://fontawesome.com/license

* https://getbootstrap.com/docs/3.3/getting-started/

* https://github.com/puikinsh/gentelella/blob/master/LICENSE.txt
